@@ -13,11 +13,10 @@
 
 import uuid
 
-import django
 from django.conf import settings
 from django.contrib import auth
-from django.core.urlresolvers import reverse
 from django import test
+from django.urls import reverse
 from keystoneauth1 import exceptions as keystone_exceptions
 from keystoneauth1.identity import v2 as v2_auth
 from keystoneauth1.identity import v3 as v3_auth
@@ -395,10 +394,7 @@ class OpenStackAuthTestsV2(OpenStackAuthTestsMixin, test.TestCase):
         response = self.client.get(url, form_data)
 
         if next:
-            if django.VERSION >= (1, 9):
-                expected_url = next
-            else:
-                expected_url = 'http://testserver%s' % next
+            expected_url = next
             self.assertEqual(response['location'], expected_url)
         else:
             self.assertRedirects(response, settings.LOGIN_REDIRECT_URL)
@@ -444,10 +440,7 @@ class OpenStackAuthTestsV2(OpenStackAuthTestsMixin, test.TestCase):
         response = self.client.get(url, form_data)
 
         if next:
-            if django.VERSION >= (1, 9):
-                expected_url = next
-            else:
-                expected_url = 'http://testserver%s' % next
+            expected_url = next
             self.assertEqual(response['location'], expected_url)
         else:
             self.assertRedirects(response, settings.LOGIN_REDIRECT_URL)
@@ -768,10 +761,7 @@ class OpenStackAuthTestsV3(OpenStackAuthTestsMixin,
         response = self.client.get(url, form_data)
 
         if next:
-            if django.VERSION >= (1, 9):
-                expected_url = next
-            else:
-                expected_url = 'http://testserver%s' % next
+            expected_url = next
             self.assertEqual(response['location'], expected_url)
         else:
             self.assertRedirects(response, settings.LOGIN_REDIRECT_URL)
@@ -816,10 +806,7 @@ class OpenStackAuthTestsV3(OpenStackAuthTestsMixin,
         response = self.client.get(url, form_data)
 
         if next:
-            if django.VERSION >= (1, 9):
-                expected_url = next
-            else:
-                expected_url = 'http://testserver%s' % next
+            expected_url = next
             self.assertEqual(response['location'], expected_url)
         else:
             self.assertRedirects(response, settings.LOGIN_REDIRECT_URL)
