@@ -37,8 +37,8 @@ We need the request object to get the user, so we'll slightly modify the
 existing django.contrib.auth.get_user method. To do so we update the
 auth middleware to point to our overridden method.
 
-Calling "patch_middleware_get_user" is done in our custom middleware at
-"openstack_auth.middleware" to monkeypatch the code in before it is needed.
+Calling the "patch_middleware_get_user" method somewhere like our urls.py
+file takes care of hooking it in appropriately.
 """
 
 
@@ -116,13 +116,6 @@ def is_safe_url(url, host=None):
     return not netloc or netloc == host
 
 
-# DEPRECATED -- Mitaka
-# This method definition is included to prevent breaking backward compatibility
-# The original functionality was problematic and has been removed.
-def remove_project_cache(token):
-    pass
-
-
 # Helper for figuring out keystone version
 # Implementation will change when API version discovery is available
 def get_keystone_version():
@@ -146,11 +139,6 @@ def get_keystone_client():
         return client_v3
 
 
-def is_token_deletion_disabled():
-    LOG.warning("Deprecated TOKEN_DELETION_DISABLED setting is no longer used")
-    return getattr(settings, 'TOKEN_DELETION_DISABLED', False)
-
-
 def is_websso_enabled():
     """Websso is supported in Keystone version 3."""
     websso_enabled = getattr(settings, 'WEBSSO_ENABLED', False)
@@ -290,27 +278,6 @@ def _augment_url_with_version(auth_url):
         return url_path_append(auth_url, "/v2.0")
 
 
-# TODO(tsufiev): remove this legacy version as soon as Horizon switches to
-# the new fix_auth_url_version_prefix() call
-def fix_auth_url_version(auth_url):
-    """Fix up the auth url if an invalid or no version prefix was given.
-
-    People still give a v2 auth_url even when they specify that they want v3
-    authentication. Fix the URL to say v3 in this case and add version if it is
-    missing entirely. This should be smarter and use discovery.
-    """
-    auth_url = _augment_url_with_version(auth_url)
-
-    if get_keystone_version() >= 3 and has_in_url_path(auth_url, ["/v2.0"]):
-        LOG.warning("The Keystone URL (either in Horizon settings or in "
-                    "service catalog) points to a v2.0 Keystone endpoint, "
-                    "but v3 is specified as the API version to use by "
-                    "Horizon. Using v3 endpoint for authentication.")
-        auth_url = url_path_replace(auth_url, "/v2.0", "/v3", 1)
-
-    return auth_url
-
-
 def fix_auth_url_version_prefix(auth_url):
     """Fix up the auth url if an invalid or no version prefix was given.
 
@@ -376,17 +343,24 @@ def get_project_list(*args, **kwargs):
 
 
 def default_services_region(service_catalog, request=None,
-                            selected_region=None):
-    """Returns the first endpoint region for first non-identity service.
+                            ks_endpoint=None):
+    """Return the default service region.
 
-    Extracted from the service catalog.
+    Order of precedence:
+    1. 'services_region' cookie value
+    2. Matching endpoint in DEFAULT_SERVICE_REGIONS
+    3. '*' key in DEFAULT_SERVICE_REGIONS
+    4. First valid region from catalog
+
+    In each case the value must also be present in available_regions or
+    we move to the next level of precedence.
     """
     if service_catalog:
         available_regions = [get_endpoint_region(endpoint) for service
                              in service_catalog for endpoint
                              in service.get('endpoints', [])
-                             if (service.get('type') is not None
-                                 and service.get('type') != 'identity')]
+                             if (service.get('type') is not None and
+                                 service.get('type') != 'identity')]
         if not available_regions:
             # this is very likely an incomplete keystone setup
             LOG.warning('No regions could be found excluding identity.')
@@ -400,12 +374,20 @@ def default_services_region(service_catalog, request=None,
                 LOG.error('No regions can be found in the service catalog.')
                 return None
 
-        if request and selected_region is None:
-            selected_region = request.COOKIES.get('services_region',
-                                                  available_regions[0])
-        if selected_region not in available_regions:
-            selected_region = available_regions[0]
-        return selected_region
+        region_options = []
+        if request:
+            region_options.append(request.COOKIES.get('services_region'))
+        if ks_endpoint:
+            default_service_regions = getattr(
+                settings, 'DEFAULT_SERVICE_REGIONS', {})
+            region_options.append(default_service_regions.get(ks_endpoint))
+        region_options.append(
+            getattr(settings, 'DEFAULT_SERVICE_REGIONS', {}).get('*'))
+
+        for region in region_options:
+            if region in available_regions:
+                return region
+        return available_regions[0]
     return None
 
 
