@@ -69,7 +69,7 @@ def login(request, template_name=None, extra_context=None, **kwargs):
         # dashboard straight away, unless the 'next' parameter is set as it
         # usually indicates requesting access to a page that requires different
         # permissions.
-        if (request.user.is_authenticated() and
+        if (request.user.is_authenticated and
                 auth.REDIRECT_FIELD_NAME not in request.GET and
                 auth.REDIRECT_FIELD_NAME not in request.POST):
             return shortcuts.redirect(settings.LOGIN_REDIRECT_URL)
@@ -92,6 +92,10 @@ def login(request, template_name=None, extra_context=None, **kwargs):
 
     extra_context['csrf_failure'] = request.GET.get('csrf_failure')
 
+    choices = getattr(settings, 'WEBSSO_CHOICES', ())
+    extra_context['show_sso_opts'] = (utils.is_websso_enabled() and
+                                      len(choices) > 1)
+
     if not template_name:
         if request.is_ajax():
             template_name = 'auth/_login.html'
@@ -114,7 +118,7 @@ def login(request, template_name=None, extra_context=None, **kwargs):
 
     # Set the session data here because django's session key rotation
     # will erase it if we set it earlier.
-    if request.user.is_authenticated():
+    if request.user.is_authenticated:
         auth_user.set_session_from_user(request, request.user)
         regions = dict(forms.Login.get_region_choices())
         region = request.user.endpoint
@@ -178,11 +182,6 @@ def logout(request, login_url=None, **kwargs):
                                                **kwargs)
 
 
-def delete_token(endpoint, token_id):
-    """Delete a token."""
-    LOG.warning("The delete_token method is deprecated and now does nothing")
-
-
 @login_required
 def switch(request, tenant_id, redirect_field_name=auth.REDIRECT_FIELD_NAME):
     """Switches an authenticated user from one project to another."""
