@@ -34,7 +34,7 @@ def flavor_list(request):
         return []
 
 
-def sort_flavor_list(request, flavors):
+def sort_flavor_list(request, flavors, with_menu_label=True):
     """Utility method to sort a list of flavors.
 
     By default, returns the available flavors, sorted by RAM usage (ascending).
@@ -57,8 +57,12 @@ def sort_flavor_list(request, flavors):
                 return get_key(flavor, sort_key)
         else:
             key = sort_key
-        flavor_list = [(flavor.id, '%s' % flavor.name)
-                       for flavor in sorted(flavors, key=key, reverse=rev)]
+
+        if with_menu_label:
+            flavor_list = [(flavor.id, '%s' % flavor.name)
+                           for flavor in sorted(flavors, key=key, reverse=rev)]
+        else:
+            flavor_list = sorted(flavors, key=key, reverse=rev)
         return flavor_list
     except Exception:
         exceptions.handle(request,
@@ -86,7 +90,8 @@ def server_group_list(request):
         return []
 
 
-def network_field_data(request, include_empty_option=False, with_cidr=False):
+def network_field_data(request, include_empty_option=False, with_cidr=False,
+                       for_launch=False):
     """Returns a list of tuples of all networks.
 
     Generates a list of networks available to the user (request). And returns
@@ -101,8 +106,12 @@ def network_field_data(request, include_empty_option=False, with_cidr=False):
     tenant_id = request.user.tenant_id
     networks = []
     if api.base.is_service_enabled(request, 'network'):
+        extra_params = {}
+        if for_launch:
+            extra_params['include_pre_auto_allocate'] = True
         try:
-            networks = api.neutron.network_list_for_tenant(request, tenant_id)
+            networks = api.neutron.network_list_for_tenant(
+                request, tenant_id, **extra_params)
         except Exception as e:
             msg = _('Failed to get network list {0}').format(six.text_type(e))
             exceptions.handle(request, msg)
