@@ -15,7 +15,7 @@
 
 import logging
 
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 from django.utils.translation import ugettext_lazy as _
 from django.utils.translation import ungettext_lazy
 
@@ -39,14 +39,6 @@ class AddAllowedAddressPair(policy.PolicyTargetMixin, tables.LinkAction):
         ("network", "update_port:allowed_address_pairs"),
     )
 
-    def get_policy_target(self, request, datum=None):
-        policy_target = super(AddAllowedAddressPair, self).\
-            get_policy_target(request, datum)
-        policy_target["network:tenant_id"] = (
-            self.table.kwargs['port'].tenant_id)
-
-        return policy_target
-
     def get_link_url(self, port=None):
         if port:
             return reverse(self.url, args=(port.id,))
@@ -76,14 +68,6 @@ class DeleteAllowedAddressPair(tables.DeleteAction):
         ("network", "update_port:allowed_address_pairs"),
     )
 
-    def get_policy_target(self, request, datum=None):
-        policy_target = super(DeleteAllowedAddressPair, self).\
-            get_policy_target(request, datum)
-        policy_target["network:tenant_id"] = (
-            self.table.kwargs['port'].tenant_id)
-
-        return policy_target
-
     def delete(self, request, ip_address):
         try:
             port_id = self.table.kwargs['port_id']
