@@ -679,8 +679,20 @@
     }
 
     function onGetVolumeSnapshots(data) {
+      cinderAPI.getVolumes({bootable: 1}).then(function (volumes) {
+        onGetBootableVolumeSnapshots(volumes.data.items, data.data.items);
+      });
+    }
+
+    function onGetBootableVolumeSnapshots(bootableVolumes, volumeSnapshots) {
+      var bootableVolumeIds = [];
+      bootableVolumes.forEach(function(volume) {
+        bootableVolumeIds.push(volume.id);
+      });
       model.volumeSnapshots.length = 0;
-      push.apply(model.volumeSnapshots, data.data.items);
+      push.apply(model.volumeSnapshots, volumeSnapshots.filter(function (volumeSnapshot) {
+        return bootableVolumeIds.indexOf(volumeSnapshot.volume_id) !== -1;
+      }));
       addAllowedBootSource(
         model.volumeSnapshots,
         bootSourceTypes.VOLUME_SNAPSHOT,
@@ -735,9 +747,11 @@
     function setFinalSpecBootImageToVolume(finalSpec) {
       if (finalSpec.vol_create) {
         // Specify null to get Autoselection (not empty string)
+        var deviceName = finalSpec.vol_device_name ? finalSpec.vol_device_name : null;
         finalSpec.block_device_mapping_v2 = [];
         finalSpec.block_device_mapping_v2.push(
           {
+            'device_name': deviceName,
             'source_type': bootSourceTypes.IMAGE,
             'destination_type': bootSourceTypes.VOLUME,
             'delete_on_termination': finalSpec.vol_delete_on_instance_delete,
