@@ -23,7 +23,7 @@ class TestVolumesBasic(helpers.TestCase):
 
     @property
     def volumes_page(self):
-        return self.home_pg.go_to_compute_volumes_volumespage()
+        return self.home_pg.go_to_project_volumes_volumespage()
 
     def test_volume_create_edit_delete(self):
         """This test case checks create, edit, delete volume functionality:
@@ -41,7 +41,7 @@ class TestVolumesBasic(helpers.TestCase):
         10. Check that the volume is absent in the list
         11. Check that no Error messages present
         """
-        volumes_page = self.home_pg.go_to_compute_volumes_volumespage()
+        volumes_page = self.home_pg.go_to_project_volumes_volumespage()
         volumes_page.create_volume(self.VOLUME_NAME)
         self.assertTrue(
             volumes_page.find_message_and_dismiss(messages.INFO))
@@ -82,12 +82,12 @@ class TestVolumesBasic(helpers.TestCase):
 
         Steps:
         1) Login to Horizon Dashboard
-        2) Go to Project -> Compute -> Volumes -> Volumes tab and create
+        2) Go to Project -> Volumes -> Volumes tab and create
         three volumes
         3) Navigate to user settings page
         4) Change 'Items Per Page' value to 1
-        5) Go to Project -> Compute -> Volumes -> Volumes tab or
-        Admin -> System -> Volumes -> Volumes tab (depends on user)
+        5) Go to Project -> Volumes -> Volumes tab or
+        Admin -> Volume -> Volumes tab (depends on user)
         6) Check that only 'Next' link is available, only one volume is
         available (and it has correct name)
         7) Click 'Next' and check that both 'Prev' and 'Next' links are
@@ -99,7 +99,7 @@ class TestVolumesBasic(helpers.TestCase):
         11) Go to user settings page and restore 'Items Per Page'
         12) Delete created volumes
         """
-        volumes_page = self.home_pg.go_to_compute_volumes_volumespage()
+        volumes_page = self.home_pg.go_to_project_volumes_volumespage()
         count = 3
         items_per_page = 1
         volumes_names = ["{0}_{1}".format(self.VOLUME_NAME, i) for i in
@@ -154,7 +154,7 @@ class TestAdminVolumes(helpers.AdminTestCase, TestVolumesBasic):
 
     @property
     def volumes_page(self):
-        return self.home_pg.go_to_system_volumes_volumespage()
+        return self.home_pg.go_to_project_volumes_volumespage()
 
 
 class TestVolumesAdvanced(helpers.TestCase):
@@ -164,16 +164,16 @@ class TestVolumesAdvanced(helpers.TestCase):
 
     @property
     def volumes_page(self):
-        return self.home_pg.go_to_compute_volumes_volumespage()
+        return self.home_pg.go_to_project_volumes_volumespage()
 
-    @decorators.skip_because(bugs=['1584057'])
+    @decorators.skip_because(bugs=['1774697'])
     def test_manage_volume_attachments(self):
         """This test case checks attach/detach actions for volume
 
         Steps:
         1. Login to Horizon Dashboard as horizon user
         2. Navigate to Project -> Compute -> Instances, create instance
-        3. Navigate to Project -> Compute -> Volumes, create volume
+        3. Navigate to Project -> Volumes -> Volumes, create volume
         4. Attach volume to instance from step2
         5. Check that volume status and link to instance
         6. Detach volume from instance
@@ -181,7 +181,7 @@ class TestVolumesAdvanced(helpers.TestCase):
         8. Delete volume and instance
         """
         instance_name = helpers.gen_random_resource_name('instance')
-        instances_page = self.home_pg.go_to_compute_instancespage()
+        instances_page = self.home_pg.go_to_project_compute_instancespage()
         instances_page.create_instance(instance_name)
         instances_page.find_message_and_dismiss(messages.SUCCESS)
         self.assertFalse(
@@ -216,7 +216,7 @@ class TestVolumesAdvanced(helpers.TestCase):
         self.assertFalse(volumes_page.find_message_and_dismiss(messages.ERROR))
         self.assertTrue(volumes_page.is_volume_deleted(self.VOLUME_NAME))
 
-        instances_page = self.home_pg.go_to_compute_instancespage()
+        instances_page = self.home_pg.go_to_project_compute_instancespage()
         instances_page.delete_instance(instance_name)
         instances_page.find_message_and_dismiss(messages.SUCCESS)
         self.assertFalse(
@@ -229,26 +229,31 @@ class TestVolumesActions(helpers.TestCase):
     IMAGE_NAME = helpers.gen_random_resource_name("image")
     INSTANCE_NAME = helpers.gen_random_resource_name("instance")
 
+    @property
+    def volumes_page(self):
+        return self.home_pg.go_to_project_volumes_volumespage()
+
     def setUp(self):
         super(TestVolumesActions, self).setUp()
-        self.volumes_page = self.home_pg.go_to_compute_volumes_volumespage()
-        self.volumes_page.create_volume(self.VOLUME_NAME)
+        volumes_page = self.volumes_page
+        volumes_page.create_volume(self.VOLUME_NAME)
         self.assertTrue(
-            self.volumes_page.find_message_and_dismiss(messages.INFO))
+            volumes_page.find_message_and_dismiss(messages.INFO))
         self.assertFalse(
-            self.volumes_page.find_message_and_dismiss(messages.ERROR))
-        self.assertTrue(self.volumes_page.is_volume_present(self.VOLUME_NAME))
-        self.assertTrue(self.volumes_page.is_volume_status(self.VOLUME_NAME,
-                                                           'Available'))
+            volumes_page.find_message_and_dismiss(messages.ERROR))
+        self.assertTrue(volumes_page.is_volume_present(self.VOLUME_NAME))
+        self.assertTrue(
+            volumes_page.is_volume_status(self.VOLUME_NAME, 'Available'))
 
         def cleanup():
-            self.volumes_page.delete_volume(self.VOLUME_NAME)
+            volumes_page = self.volumes_page
+            volumes_page.delete_volume(self.VOLUME_NAME)
             self.assertTrue(
-                self.volumes_page.find_message_and_dismiss(messages.SUCCESS))
+                volumes_page.find_message_and_dismiss(messages.SUCCESS))
             self.assertFalse(
-                self.volumes_page.find_message_and_dismiss(messages.ERROR))
+                volumes_page.find_message_and_dismiss(messages.ERROR))
             self.assertTrue(
-                self.volumes_page.is_volume_deleted(self.VOLUME_NAME))
+                volumes_page.is_volume_deleted(self.VOLUME_NAME))
 
         self.addCleanup(cleanup)
 
@@ -262,18 +267,19 @@ class TestVolumesActions(helpers.TestCase):
         4. Check that the volume is still in the list
         5. Check that the volume size is changed
         """
-        orig_size = self.volumes_page.get_size(self.VOLUME_NAME)
-        self.volumes_page.extend_volume(self.VOLUME_NAME, orig_size + 1)
+        volumes_page = self.volumes_page
+        orig_size = volumes_page.get_size(self.VOLUME_NAME)
+        volumes_page.extend_volume(self.VOLUME_NAME, orig_size + 1)
         self.assertTrue(
-            self.volumes_page.find_message_and_dismiss(messages.INFO))
+            volumes_page.find_message_and_dismiss(messages.INFO))
         self.assertFalse(
-            self.volumes_page.find_message_and_dismiss(messages.ERROR))
-        self.assertTrue(self.volumes_page.is_volume_status(self.VOLUME_NAME,
-                                                           'Available'))
-        new_size = self.volumes_page.get_size(self.VOLUME_NAME)
+            volumes_page.find_message_and_dismiss(messages.ERROR))
+        self.assertTrue(
+            volumes_page.is_volume_status(self.VOLUME_NAME, 'Available'))
+        new_size = volumes_page.get_size(self.VOLUME_NAME)
         self.assertLess(orig_size, new_size)
 
-    @decorators.skip_because(bugs=['1584057'])
+    @decorators.skip_because(bugs=['1774697'])
     def test_volume_upload_to_image(self):
         """This test case checks upload volume to image functionality:
 
@@ -284,7 +290,7 @@ class TestVolumesActions(helpers.TestCase):
         4. Delete the image
         5. Repeat actions for all disk formats
         """
-        self.volumes_page = self.home_pg.go_to_compute_volumes_volumespage()
+        self.volumes_page = self.home_pg.go_to_project_volumes_volumespage()
         all_formats = {"qcow2": u'QCOW2', "raw": u'Raw', "vdi": u'VDI',
                        "vmdk": u'VMDK'}
         for disk_format in all_formats:
@@ -295,7 +301,7 @@ class TestVolumesActions(helpers.TestCase):
                 self.volumes_page.find_message_and_dismiss(messages.ERROR))
             self.assertTrue(self.volumes_page.is_volume_status(
                 self.VOLUME_NAME, 'Available'))
-            images_page = self.home_pg.go_to_compute_imagespage()
+            images_page = self.home_pg.go_to_project_compute_imagespage()
             self.assertTrue(images_page.is_image_present(self.IMAGE_NAME))
             self.assertTrue(images_page.is_image_active(self.IMAGE_NAME))
             self.assertEqual(images_page.get_image_format(self.IMAGE_NAME),
@@ -307,8 +313,9 @@ class TestVolumesActions(helpers.TestCase):
                 messages.ERROR))
             self.assertFalse(images_page.is_image_present(self.IMAGE_NAME))
             self.volumes_page = \
-                self.home_pg.go_to_compute_volumes_volumespage()
+                self.home_pg.go_to_project_volumes_volumespage()
 
+    @decorators.skip_because(bugs=['1774697'])
     def test_volume_launch_as_instance(self):
         """This test case checks launch volume as instance functionality:
 
@@ -325,18 +332,18 @@ class TestVolumesActions(helpers.TestCase):
             self.volumes_page.find_message_and_dismiss(messages.SUCCESS))
         self.assertFalse(
             self.volumes_page.find_message_and_dismiss(messages.ERROR))
-        instances_page = self.home_pg.go_to_compute_instancespage()
+        instances_page = self.home_pg.go_to_project_compute_instancespage()
         self.assertTrue(instances_page.is_instance_active(self.INSTANCE_NAME))
-        self.volumes_page = self.home_pg.go_to_compute_volumes_volumespage()
+        self.volumes_page = self.home_pg.go_to_project_volumes_volumespage()
         self.assertTrue(self.volumes_page.is_volume_status(self.VOLUME_NAME,
                                                            'In-use'))
         self.assertIn(self.INSTANCE_NAME,
                       self.volumes_page.get_attach_instance(self.VOLUME_NAME))
-        instances_page = self.home_pg.go_to_compute_instancespage()
+        instances_page = self.home_pg.go_to_project_compute_instancespage()
         instances_page.delete_instance(self.INSTANCE_NAME)
         self.assertTrue(
             instances_page.find_message_and_dismiss(messages.SUCCESS))
         self.assertFalse(
             instances_page.find_message_and_dismiss(messages.ERROR))
         self.assertTrue(instances_page.is_instance_deleted(self.INSTANCE_NAME))
-        self.volumes_page = self.home_pg.go_to_compute_volumes_volumespage()
+        self.volumes_page = self.home_pg.go_to_project_volumes_volumespage()
